log using "C:\ifolder\Stata\KIDS-III\duplicatefix_final.smcl", replace

* duplicatefix_final.do
* Author: Alessandra Garbero
* Date: 16 March 2006
* Last revised: 24 January 2007 (IMT)

* Drops duplicate households (hhid2004 : 223016303, 234032004, 236006005, 241004001) from hhcard & section 2-13.
* Checks for and eliminates duplicate records in every section of the questionnaire.

*STATA Version 9.2

clear
set mem 256m
cd "J:\CPS\STAFF\IAN\KIDS2004v1.1\KIDS2004\Jan07"

* HHCARD

use "hhcard", clear
sort hhid2004
duplicates tag hhid2004 pcode, generate(flag)
tab flag

drop if flag==1 & circ==2
drop flag
duplicates tag hhid2004 pcode, generate(flag)
tab flag

*Doublecheck:
list hhid2004 if hhid2004==223016303
list hhid2004 if hhid2004==234032004
list hhid2004 if hhid2004==236006005
list hhid2004 if hhid2004==241004001

drop if hhid2004==236006005 
drop if hhid2004==241004001
drop flag

compress
saveold "hhcard", replace

*SECTION 2.

use "section2", clear
sort hhid2004
duplicates tag hhid2004, generate(flag)
tab flag

*Doublecheck:
list hhid2004 if hhid2004==223016303
list hhid2004 if hhid2004==234032004
list hhid2004 if hhid2004==236006005
list hhid2004 if hhid2004==241004001

drop if hhid2004==236006005 
drop if hhid2004==241004001
drop flag

compress
saveold "section2", replace

*Section 3
use "section3", clear
sort  hhid2004 cluster qtype foodcode
duplicates tag hhid2004 cluster qtype foodcode, generate(flag)
tab flag

*Doublecheck:
list hhid2004 if hhid2004==223016303
list hhid2004 if hhid2004==234032004
list hhid2004 if hhid2004==236006005
list hhid2004 if hhid2004==241004001

*only the latter 2 hhs are present; check further:
list hhid2004 cluster qtype foodcode if hhid2004==241004001
list hhid2004 cluster qtype foodcode if hhid2004==236006005

drop if hhid2004==236006005 
drop if hhid2004==241004001
drop flag

compress
saveold "section3", replace


*Section 4_1
use "section4_1",clear
sort hhid2004 rnfs_c
duplicates tag hhid2004 rnfs_c, generate(flag)
tab flag

*Doublecheck:
list hhid2004 if hhid2004==223016303
list hhid2004 if hhid2004==234032004
list hhid2004 if hhid2004==236006005
list hhid2004 if hhid2004==241004001

*Only the latter 2 hhs are present in the file:
list if hhid2004==236006005
list if hhid2004==241004001

drop if hhid2004==236006005 
drop if hhid2004==241004001
drop flag

compress
saveold "section4_1", replace

*Section 4_2
use "section4_2", clear
sort hhid2004 onfs_c
duplicates tag hhid2004 onfs_c, generate(flag)
tab flag

*Doublecheck:
list hhid2004 if hhid2004==223016303
list hhid2004 if hhid2004==234032004
list hhid2004 if hhid2004==236006005
list hhid2004 if hhid2004==241004001

*Only the latter 2 hhs are present in the file:
list if hhid2004==236006005
list if hhid2004==241004001

drop if hhid2004==236006005 
drop if hhid2004==241004001
drop flag

compress
saveold "section4_2", replace

*Section 4_3
use "section4_3", clear
sort hhid2004 durable
duplicates tag hhid2004 durable, generate(flag)
tab flag

*Doublecheck:
list hhid2004 if hhid2004==223016303
list hhid2004 if hhid2004==234032004
list hhid2004 if hhid2004==236006005
list hhid2004 if hhid2004==241004001


*Only the latter 2 hhs are present in the file:
list if hhid2004==236006005
list if hhid2004==241004001

drop if hhid2004==236006005 
drop if hhid2004==241004001
drop flag

compress
saveold "section4_3", replace

*************************************************************************
*************************************************************************
*Section 4_4
use "section4_4", clear
sort  hhid2004 line
duplicates tag, generate(flag)
tab flag

*There are two duplicate records, probably entered twice.
list hhid2004 if flag==1

drop if flag==1 & flag[_n-1]==1

*Doublecheck:
list hhid2004 if hhid2004==223016303
list hhid2004 if hhid2004==234032004
list hhid2004 if hhid2004==236006005
list hhid2004 if hhid2004==241004001

*Only the latter 2 hhs are present in the file:
list  hhid2004 cluster qtype resp line if hhid2004==236006005
list  hhid2004 cluster qtype resp line if hhid2004==241004001

drop if hhid2004==236006005 
drop if hhid2004==241004001
drop flag
duplicates tag hhid2004 line, generate(flag)
list hhid2004 line if flag>0 & line<24
drop flag

compress
saveold "section4_4", replace 
*************************************************************************

*Section 4_5
use "section4_5", clear
sort  hhid2004 line
duplicates tag hhid2004 line, generate(flag)
tab flag

*Doublecheck:
list hhid2004 if hhid2004==223016303
list hhid2004 if hhid2004==234032004
list hhid2004 if hhid2004==236006005
list hhid2004 if hhid2004==241004001

*Only HHID2004=236006005 is present in the file.
list if hhid2004==236006005

drop if hhid2004==236006005 
drop flag

compress
saveold "section4_5", replace 

*Section 5_1
use "section5_1", clear
sort hhid2004 line
duplicates tag hhid2004 line, generate(flag)
tab flag

*Doublecheck:
list hhid2004 if hhid2004==223016303
list hhid2004 if hhid2004==234032004
list hhid2004 if hhid2004==236006005
list hhid2004 if hhid2004==241004001

*Only the latter 2 hhs are present in the file:
list if hhid2004==236006005
list if hhid2004==241004001

drop if hhid2004==236006005 
drop if hhid2004==241004001
drop flag

compress
saveold "section5_1", replace 

*Section 5_2
use "section5_2", clear
sort  hhid2004 line
duplicates tag hhid2004 line, generate(flag)
tab flag

*Doublecheck:
list hhid2004 if hhid2004==223016303
list hhid2004 if hhid2004==234032004
list hhid2004 if hhid2004==236006005
list hhid2004 if hhid2004==241004001

*Only the latter 2 hhs are present in the file:
list if hhid2004==236006005
list if hhid2004==241004001

drop if hhid2004==236006005 
drop if hhid2004==241004001
drop flag

compress
saveold "section5_2", replace

*Section 6
use "section6", clear 
sort  hhid2004 source_c
duplicates tag hhid2004 source_c, generate(flag)
tab flag


*Doublecheck:
list hhid2004 if hhid2004==223016303
list hhid2004 if hhid2004==234032004
list hhid2004 if hhid2004==236006005
list hhid2004 if hhid2004==241004001

*Only hhid2004==241004001 is present.
list if hhid2004==241004001

drop if hhid2004==241004001
drop flag

compress
saveold "section6", replace


*Section 7_1
use "section7_1", clear 
sort  hhid2004  shock
order  hhid2004 cluster qtype resp shock nshock month year shock_dte duration duratiow income_d expense itmvalue
duplicates tag hhid2004 shock, generate(flag)
list hhid2004 shock flag if flag>0 & shock<11

*Doublecheck:

list hhid2004 if hhid2004==223016303
list hhid2004 if hhid2004==234032004
list hhid2004 if hhid2004==236006005
list hhid2004 if hhid2004==241004001

*Only the latter 2 hhs are present in the file:
list hhid2004 shock if hhid2004==236006005
list hhid2004 shock if hhid2004==241004001

drop if hhid2004==236006005 
drop if hhid2004==241004001
drop flag

compress
saveold "section7_1", replace


*Section 7_2
use "section7_2", clear 
sort  hhid2004 shock 
duplicates tag hhid2004 shock, generate(flag)
list hhid2004 shock flag if flag>0 & shock<19

*Doublecheck:

list hhid2004 if hhid2004==223016303
list hhid2004 if hhid2004==234032004
list hhid2004 if hhid2004==236006005
list hhid2004 if hhid2004==241004001

*Only the latter 2 hhs are present in the file:
list hhid2004 shock if hhid2004==236006005
list hhid2004 shock if hhid2004==241004001

drop if hhid2004==236006005 
drop if hhid2004==241004001
drop flag

compress
saveold "section7_2", replace

*************************************************************************************.
*************************************************************************************.
*************************************************************************************.
*Section 8_1_1
use "section8_1_1", clear 
sort  hhid2004 agcode

*Check whether agcode entry different from N/A when household members do not participate in agricultural activities.

list hhid2004 if  agcode>-2 & agpart==2

duplicates tag hhid2004 agcode, generate(flag)
tab flag

*Doublecheck:

list hhid2004 if hhid2004==223016303
list hhid2004 if hhid2004==234032004
list hhid2004 if hhid2004==236006005
list hhid2004 if hhid2004==241004001

*Only the latter 2 hhs are present in the file:
list hhid2004 agcode if hhid2004==236006005
list hhid2004 agcode if hhid2004==241004001

drop if hhid2004==236006005 
drop if hhid2004==241004001
drop flag

compress
saveold "section8_1_1", replace


*Section 8_1_2
use "section8_1_2", clear 
sort  hhid2004 plot_no
duplicates tag hhid2004 plot_no, generate(flag)
tab flag

tab  plot_sze, nolabel
list if  plotlie_yn==2 &  plot_sze>-2

*Doublecheck:

list hhid2004 if hhid2004==223016303
list hhid2004 if hhid2004==234032004
list hhid2004 if hhid2004==236006005
list hhid2004 if hhid2004==241004001

*Only the latter 2 hhs are present in the file:

list hhid2004 plot_no if hhid2004==236006005
list hhid2004 plot_no if hhid2004==241004001


drop if hhid2004==236006005 
drop if hhid2004==241004001
drop flag

compress
saveold "section8_1_2", replace



*Section 8_1_3
use "section8_1_3", clear 
sort  hhid2004 line 
duplicates tag hhid2004 line, generate(flag)
tab flag

list hhid2004 if crop_yn==2 & crop>=1 & crop<=24

*Doublecheck:
list hhid2004 if hhid2004==223016303
list hhid2004 if hhid2004==234032004
list hhid2004 if hhid2004==236006005
list hhid2004 if hhid2004==241004001

*Only the latter 2 hhs are present in the file:
list if hhid2004==236006005
list if hhid2004==241004001

drop if hhid2004==236006005 
drop if hhid2004==241004001
drop flag

compress
saveold "section8_1_3", replace


*Section 8_1_4a
use "section8_1_4a", clear 
sort  hhid2004 act
duplicates tag hhid2004 act, generate(flag)
tab flag

list  hhid2004 if  tcrhire==2 &  tcrh_yn==1 

*Doublecheck:

list hhid2004 if hhid2004==223016303
list hhid2004 if hhid2004==234032004
list hhid2004 if hhid2004==236006005
list hhid2004 if hhid2004==241004001

*Only the latter 2 hhs are present in the file:
list if hhid2004==236006005
list if hhid2004==241004001

drop if hhid2004==236006005 
drop if hhid2004==241004001
drop flag

compress
saveold "section8_1_4a", replace



*Section 8_1_4b
use "section8_1_4b", clear 
sort  hhid2004 input 
duplicates tag hhid2004 input, generate(flag)
tab flag

tab input
tab input,nolabel
list if  inputs_yn==2 & input>-2 & input <=9

*Doublecheck:
list hhid2004 if hhid2004==223016303
list hhid2004 if hhid2004==234032004
list hhid2004 if hhid2004==236006005
list hhid2004 if hhid2004==241004001

*Only the latter 2 hhs are present in the file:
list if hhid2004==236006005
list if hhid2004==241004001

drop if hhid2004==236006005 
drop if hhid2004==241004001
drop flag

compress
saveold "section8_1_4b", replace


*Section 8_1_4linear
use "section8_1_4linear", clear 
sort  hhid2004 
duplicates tag hhid2004, generate(flag)
tab flag

*Doublecheck:
list hhid2004 if hhid2004==223016303
list hhid2004 if hhid2004==234032004
list hhid2004 if hhid2004==236006005
list hhid2004 if hhid2004==241004001

*Only the latter 2 hhs are present in the file:
list if hhid2004==236006005
list if hhid2004==241004001

drop if hhid2004==236006005 
drop if hhid2004==241004001
drop flag

compress
saveold "section8_1_4linear", replace



*Section 8_2_1
use "section8_2_1", clear 
sort  hhid2004 lvstact
duplicates tag hhid2004 lvstact, generate(flag)
tab flag

tab  lvstacp
tab  lvstacp,nolabel
*check whether no hh member participates to grazing and production activities (filter) and invalid entry in lvstacp.  
list hhid2004  if  lvstck==2  & lvstacp==1

*Doublecheck:
list hhid2004 if hhid2004==223016303
list hhid2004 if hhid2004==234032004
list hhid2004 if hhid2004==236006005
list hhid2004 if hhid2004==241004001

*Only the latter 2 hhs are present in the file:
list if hhid2004==236006005
list if hhid2004==241004001

drop if hhid2004==236006005 
drop if hhid2004==241004001
drop flag

compress
saveold "section8_2_1", replace


*Section 8_2_2

use "section8_2_2", clear
sort  hhid2004 plot_no
duplicates tag hhid2004 plot_no, generate(flag)
tab flag

tab plot_no
tab plot_no, nolabel
tab  plot_no if plotrent==1

list hhid2004 if plotrent==2 & plot_no>-2


*Doublecheck:
list hhid2004 if hhid2004==223016303
list hhid2004 if hhid2004==234032004
list hhid2004 if hhid2004==236006005
list hhid2004 if hhid2004==241004001

*Only the latter 2 hhs are present in the file:
list if hhid2004==236006005
list if hhid2004==241004001

drop if hhid2004==236006005 
drop if hhid2004==241004001
drop flag

compress
saveold "section8_2_2", replace

*Section 8_2_3
use "section8_2_3", clear
sort  hhid2004 code 
duplicates tag hhid2004 code, generate(flag)
tab flag

tab code
tab tanim_yn, nolabel
list hhid if  tanim_yn==2 &  anim_yn==1


*Doublecheck:
list hhid2004 if hhid2004==223016303
list hhid2004 if hhid2004==234032004
list hhid2004 if hhid2004==236006005
list hhid2004 if hhid2004==241004001

*Only the latter 2 hhs are present in the file:
list hhid2004 code if hhid2004==236006005
list hhid2004 code if hhid2004==241004001

drop if hhid2004==236006005 
drop if hhid2004==241004001
drop flag

compress
saveold "section8_2_3", replace
 

*Section 8_3
use "section8_3", clear
sort  hhid2004 product
duplicates tag hhid2004 product, generate(flag)
tab flag

tab product
tab product, nolabel
list  hhid2004 if  animprod==2 &  product>-2

*Doublecheck:
list hhid2004 if hhid2004==223016303
list hhid2004 if hhid2004==234032004
list hhid2004 if hhid2004==236006005
list hhid2004 if hhid2004==241004001

*Only the latter 2 hhs are present in the file:
list if hhid2004==236006005
list if hhid2004==241004001

drop if hhid2004==236006005 
drop if hhid2004==241004001
drop flag

compress
saveold "section8_3", replace

*Section 8_4
use "section8_4", clear
sort  hhid2004 lvstact
duplicates tag hhid2004 lvstact, generate(flag)
tab flag

tab  tanhire, nolabel
tab  tanh_yn
list hhid2004 if tanhire==2 & tanh_yn==1

*Doublecheck:
list hhid2004 if hhid2004==223016303
list hhid2004 if hhid2004==234032004
list hhid2004 if hhid2004==236006005
list hhid2004 if hhid2004==241004001

*Only the latter 2 hhs are present in the file:
list if hhid2004==236006005
list if hhid2004==241004001

drop if hhid2004==236006005 
drop if hhid2004==241004001
drop flag

compress
saveold "section8_4",replace

*Section 8_5

use "section8_5", clear
sort  hhid2004 wkrtyp
duplicates tag hhid2004 wkrtyp, generate(flag)
tab flag

tab  wkrtyp permhire_yn

list hhid2004 wkrtyp numwkr if permhire_yn==2 
*String variable with 1,169 missing. checked further:
encode wkrtyp, gen(temp)
tab temp, nolabel
tab temp, nolabel miss


*Doublecheck:
list hhid2004 if hhid2004==223016303
list hhid2004 if hhid2004==234032004
list hhid2004 if hhid2004==236006005
list hhid2004 if hhid2004==241004001


*Only the latter 2 hhs are present in the file:
list if hhid2004==236006005
list if hhid2004==241004001

drop if hhid2004==236006005 
drop if hhid2004==241004001
drop flag

compress
saveold "section8_5",replace

*Section 8_6
use "section8_6", clear
sort  hhid2004 incsrce 
duplicates tag hhid2004 incsrce, generate(flag)
tab flag

*Doublecheck:
list hhid2004 if hhid2004==223016303
list hhid2004 if hhid2004==234032004
list hhid2004 if hhid2004==236006005
list hhid2004 if hhid2004==241004001


*Only the latter 2 hhs are present in the file:
list if hhid2004==236006005
list if hhid2004==241004001


drop if hhid2004==236006005 
drop if hhid2004==241004001
drop flag

compress
saveold "section8_6",replace

*Section 9_1
use "section9_1", clear
sort hhid2004 pcode
duplicates tag hhid2004 pcode, generate(flag)
tab flag

*Doublecheck:
list hhid2004 if hhid2004==223016303
list hhid2004 if hhid2004==234032004
list hhid2004 if hhid2004==236006005
list hhid2004 if hhid2004==241004001

*Only the latter 2 hhs are present in the file:
list if hhid2004==236006005
list if hhid2004==241004001


drop if hhid2004==236006005 
drop if hhid2004==241004001
drop flag

compress
saveold "section9_1",replace

*Section 9_2
use "section9_2", clear
sort  hhid2004 pcode 
duplicates tag hhid2004 pcode, generate(flag)
tab flag


*Doublecheck:
list hhid2004 if hhid2004==223016303
list hhid2004 if hhid2004==234032004
list hhid2004 if hhid2004==236006005
list hhid2004 if hhid2004==241004001

*Only 1 hh is present in the file:
list if hhid2004==236006005

drop if hhid2004==236006005 
drop flag

compress
saveold "section9_2",replace

*Section 9_3
use "section9_3", clear
sort  hhid2004 line
duplicates tag hhid2004 pcode jobno, generate(flag)
tab flag


*Doublecheck:
list hhid2004 if hhid2004==223016303
list hhid2004 if hhid2004==234032004
list hhid2004 if hhid2004==236006005
list hhid2004 if hhid2004==241004001

*Only 1 hh is present in the file:
list if hhid2004==241004001

drop if hhid2004==241004001
drop flag

compress
saveold "section9_3",replace


*Section 9_4
use "section9_4", clear
sort  hhid2004 business
duplicates tag hhid2004 business, generate(flag)
tab flag

list  hhid2004 business mcode1_c mcode2_c mcode3_c if flag==1
*Found 3 missing values for business when filter==1 (respondent indicated presence of self-employment).
list hhid2004 business if  work_addl==1 & business<1 & business ==!.  

*Doublecheck:
list hhid2004 if hhid2004==223016303
list hhid2004 if hhid2004==234032004
list hhid2004 if hhid2004==236006005
list hhid2004 if hhid2004==241004001

*Only the latter 2 hhs are present in the file:
list if hhid2004==236006005
list if hhid2004==241004001

 
drop if hhid2004==236006005 
drop if hhid2004==241004001
drop flag

compress
saveold "section9_4",replace



*Section 9_5
use "section9_5", clear
sort  hhid2004 pcode 
duplicates tag hhid2004 pcode , generate(flag)
tab flag

*Doublecheck:
list hhid2004 if hhid2004==223016303
list hhid2004 if hhid2004==234032004
list hhid2004 if hhid2004==236006005
list hhid2004 if hhid2004==241004001

*Only 1 hh is present in the file:

list if hhid2004==241004001

drop if hhid2004==241004001
drop flag

compress
saveold "section9_5",replace


*Section 9_6a
use "section9_6a", clear
sort  hhid2004 pcode 
duplicates report
duplicates tag hhid2004 pcode jobno, generate(flag)
tab flag

tab wrktype
tab wrktype, nolabel
sum hhid2004 if  work_s93==2 &  wrktype<1
*Doublecheck:
list hhid2004 if hhid2004==223016303
list hhid2004 if hhid2004==234032004
list hhid2004 if hhid2004==236006005
list hhid2004 if hhid2004==241004001


*Only 1 hh is present in the file:
list if hhid2004==241004001

drop if hhid2004==241004001
drop flag

compress
saveold "section9_6a",replace

*Section 10_1
use "section10_1", clear
sort  hhid2004 pcode 
duplicates tag hhid2004 pcode, generate(flag)
tab flag
duplicates report

*checking filter.
list if  ill_yn==1 &  pcode==!.

*Doublecheck:
list hhid2004 if hhid2004==223016303
list hhid2004 if hhid2004==234032004
list hhid2004 if hhid2004==236006005
list hhid2004 if hhid2004==241004001

*Only 1 hh is present in the file:
list if hhid2004==241004001

drop if hhid2004==241004001
drop flag

compress
saveold "section10_1",replace


*Section 10_2
use "section10_2", clear
sort  hhid2004 pcode
duplicates tag hhid2004 pcode, generate(flag)
tab flag

list hhid2004 if  (birth_yn==2 &  birth_lwm==0 &  birth_le==0)


*Doublecheck:
list hhid2004 if hhid2004==223016303
list hhid2004 if hhid2004==234032004
list hhid2004 if hhid2004==236006005
list hhid2004 if hhid2004==241004001


*Only the latter 2 hhs are present in the file:
list if hhid2004==236006005
list if hhid2004==241004001

 
drop if hhid2004==236006005 
drop if hhid2004==241004001
drop flag

compress
saveold "section10_2",replace

*Section 10_3
use "section10_3", clear
sort  hhid2004 pcode 
duplicates tag hhid2004 pcode , generate(flag)
tab flag

*Doublecheck:
list hhid2004 if hhid2004==223016303
list hhid2004 if hhid2004==234032004
list hhid2004 if hhid2004==236006005
list hhid2004 if hhid2004==241004001

*Only the latter 2 hhs are present in the file:
list if hhid2004==236006005
list if hhid2004==241004001

drop if hhid2004==236006005 
drop if hhid2004==241004001
drop flag

compress
saveold "section10_3",replace


*Section 11_1
use "section11_1", clear
sort  hhid2004 pcode 
duplicates report
duplicates tag hhid2004 pcode, generate(flag)
tab flag

*Doublecheck:
list hhid2004 if hhid2004==223016303
list hhid2004 if hhid2004==234032004
list hhid2004 if hhid2004==236006005
list hhid2004 if hhid2004==241004001

*Only the latter 2 hhs are present in the file:
list if hhid2004==236006005
list if hhid2004==241004001

drop if hhid2004==236006005 
drop if hhid2004==241004001
drop flag

compress
saveold "section11_1",replace

*Section 11_2_1
use "section11_2_1", clear
sort  hhid2004 pcode
duplicates report
duplicates tag hhid2004 pcode, generate(flag)
tab flag

tab safemal

*Doublecheck:
list hhid2004 if hhid2004==223016303
list hhid2004 if hhid2004==234032004
list hhid2004 if hhid2004==236006005
list hhid2004 if hhid2004==241004001

*Only the latter 2 hhs are present in the file:
list if hhid2004==236006005
list if hhid2004==241004001

drop if hhid2004==236006005 
drop if hhid2004==241004001
drop flag

compress
saveold "section11_2_1",replace

*Section 11_2_2
use "section11_2_2", clear
sort  hhid2004 pcode 
duplicates report
duplicates tag hhid2004 pcode, generate(flag)
tab flag

*Doublecheck:
list hhid2004 if hhid2004==223016303
list hhid2004 if hhid2004==234032004
list hhid2004 if hhid2004==236006005
list hhid2004 if hhid2004==241004001

drop if hhid2004==236006005 
drop if hhid2004==241004001
drop flag

compress
saveold "section11_2_2",replace

**********************************************************************
**********************************************************************
*Section 11_3a
use "section11_3a", clear
sort  hhid2004 group 
duplicates report
duplicates tag hhid2004 group, generate(flag)
tab flag

*
* household 206004024 was entered a second time with qtype==1
*
drop if hhid2004==206004024 & qtype==1
drop flag
duplicates tag hhid2004 group, generate(flag)
tab flag

*Doublecheck:
list hhid2004 if hhid2004==223016303
list hhid2004 if hhid2004==234032004
list hhid2004 if hhid2004==236006005
list hhid2004 if hhid2004==241004001

*Only the latter 2 hhs are present in the file:
list if hhid2004==236006005
list if hhid2004==241004001

drop if hhid2004==236006005 
drop if hhid2004==241004001
drop flag

compress
saveold "section11_3a", replace
*************************************************************************

*Section 11_3b
use "section11_3b", clear
sort hhid2004 church_cd
duplicates report
duplicates tag hhid2004 church_cd, generate(flag)
tab flag

list  hhid2004 church_cd pcode1 pcode2 pcode3 pcode4 if flag==1


*Doublecheck:
list hhid2004 if hhid2004==223016303
list hhid2004 if hhid2004==234032004
list hhid2004 if hhid2004==236006005
list hhid2004 if hhid2004==241004001


*Only the latter 2 hhs are present in the file:
list hhid2004 cluster qtype church_cd if hhid2004==236006005
list hhid2004 cluster qtype church_cd if hhid2004==241004001

drop if hhid2004==236006005 
drop if hhid2004==241004001
drop flag

compress
saveold "section11_3b", replace

********************************************************************
********************************************************************
**Section 12_1
use "section12_1", clear
sort  hhid2004 child
duplicates report
duplicates tag hhid2004 child, generate(flag)
tab flag

*6 Duplicate records present, inspect:
list  hhid2004 child care if flag==1
duplicates drop 
*dropped duplicates.

*Doublecheck:
list hhid2004 if hhid2004==223016303
list hhid2004 if hhid2004==234032004
list hhid2004 if hhid2004==236006005
list hhid2004 if hhid2004==241004001

*Only the latter 2 hhs are present in the file:

drop if hhid2004==236006005 
drop if hhid2004==241004001
drop flag

compress
saveold "section12_1", replace
*******************************************************************

**Section 12_2
use "section12_2", clear
sort  hhid2004 pcode
duplicates report 
duplicates tag hhid2004 pcode, generate(flag)
tab flag

*Doublecheck:
list hhid2004 if hhid2004==223016303
list hhid2004 if hhid2004==234032004
list hhid2004 if hhid2004==236006005
list hhid2004 if hhid2004==241004001

*Only the latter 2 hhs are present in the file:
list if hhid2004==236006005
list if hhid2004==241004001

drop if hhid2004==236006005 
drop if hhid2004==241004001
drop flag

compress
saveold "section12_2", replace

**Section 13_1
use "section13_1", clear
sort  hhid2004 pcode 
duplicates report
duplicates tag hhid2004 pcode, generate(flag)
tab flag

*Doublecheck:
list hhid2004 if hhid2004==223016303
list hhid2004 if hhid2004==234032004
list hhid2004 if hhid2004==236006005
list hhid2004 if hhid2004==241004001

*there are none of the above

drop flag
compress
saveold "section13_1", replace

**Section 13_2
use "section13_2", clear
sort  hhid2004 pcode
duplicates report 
duplicates tag hhid2004 pcode, generate(flag)
tab flag

*Doublecheck:
list hhid2004 if hhid2004==223016303
list hhid2004 if hhid2004==234032004
list hhid2004 if hhid2004==236006005
list hhid2004 if hhid2004==241004001

*Only the last 1 is  present in the file:
list if hhid2004==241004001

drop if hhid2004==241004001
drop flag

compress
saveold "section13_2", replace

*Section 13_3
use "section13_3", clear
sort  hhid2004 pcode 
duplicates report
duplicates tag hhid2004 pcode, generate(flag)
tab flag

*Doublecheck:
list hhid2004 if hhid2004==223016303
list hhid2004 if hhid2004==234032004
list hhid2004 if hhid2004==236006005
list hhid2004 if hhid2004==241004001

*there are none of the above

drop flag

compress
saveold "section13_3", replace

log close
