capture log close
log using "c:\ifolder\Stata\KIDS-III\Log files\roster_dates_Mar07.smcl", replace
*
* roster_dates.do
* Author: Ian Timaeus
* Date: 3 October 2004
* Last revised: 14 Mar 2007 to check DRA info on whether deaths occurred +/- 1998 and 
*                           output records where alive98 should be 2 in roster_panel
*               27 Jan 2007 to set 2 missing values on a7d to date1
*               29 Aug 2006 to keep distinct individuals with pcode>40 and drop 
*                           duplicates with pcode>40 from 1998
*               28 Nov 2005 to drop 5 duplicate reports on the deaths of people living 
*                           in different split households in 1998
*
* Cleans raw roster data (19044 records, dated 2/3/2005)
*
* 1) Drops null roster records (314)
* 2) Drops pre-printed records for non-members of next generation and foster households
* 3) Drops duplicate records for the 4 households that were interviewed twice
* 4) Drops records for non-members of core households if died before 1998 or they belong
*    to another household and are not mentioned in section 1.4 
* 5) Drops ALL null and duplicated reports on deaths, usually keeping the report made by
*    the dead person's 1998 household 
* 6) Reconciles each roster record with pcode <100 with the 1998 roster
* 7) Creates valid roster record and cover record for deaths in extinct core households
* 8) Calculates age_dob using dates of birth if available and the 1998 age if the 
*    2004 data are missing/impossible
* 9) Tidies up some other variables, data entry errors, and label conflicts
*
clear
set mem 256m
cd "c:\ifolder\Stata\KIDS-III\roster1_1\"
use "cover raw", clear
replace a7d=date1 if a7d==. & date1<. & qtype>0
label val agree_yn q2
sort hhid2004
save temp_cover, replace
*
* SECTION 1.4
*
use "section1_4 raw", clear
drop a1
rename qtype ckn
sort hhid2004
merge hhid2004 using temp_cover, keep(qtype)
tab _merge qtype, m
drop if _merge<3
list hhid2004 ckn qtype if ckn~=qtype 
label drop qtype
drop _merge
*
sort hhid2004 pcode
merge hhid2004 pcode using "roster2004 raw", unique
tab _merge alive, m
list hhid2004 pcode qtype if _merge==1 & pcode>0
*
gen s1_4_flag=(_merge==3)
drop ckn 
label var hhid2004 "9-digit KIDS-III household ID"
save temp, replace
drop if _merge==2
rename pcode dec_makr
label var dec_makr "person code of decision maker"
keep hhid2004 dec_makr
sort hhid2004 dec_makr
save section1_4, replace
*
use temp, clear
drop if _merge==1
drop _merge
tab s1_4_flag
sort hhid2004 pcode
save temp_roster, replace
*
* SECTION 1_3
*
* drop null death records created during data entry for households with no deaths
*
use "section1_3 full.dta", clear /* dated 31/3/2005: 1142 records; 460 with pcode==-2 */
drop if pcode==-2
*
* drop "extinct core" section 1.3s for 2 deaths whose 1998 household was actually surviving
* and the 2nd section 1.3 record for 1 death in an extinct household that was reported twice
*
drop if hhid2004==225021000 & ckn==-2
drop if hhid2004==197006000 & pcode==1 & die_datm==9
*
* clean up mistyped dates
*
replace die_daty=2004 if die_daty==204
replace die_daty=-4 if die_daty==1995
*
* set dates of death to mid-month
*
replace die_date=mdy(die_datm,15,die_daty) if die_datm>0 & die_daty>0
replace die_date=die_date-1 if die_daty>0 & die_datm==2
replace die_date=. if die_datm<0 | die_daty<0
*
drop draid qesnum a1 hhid_DRA
*
* generate new total expenditure before death
*
gen byte miss = 0
replace miss = (med_c<0)+(travel_c<0)+(health_c<0)+(hosp_c<0)+(other_c<0) 
gen long tot_c_edt = med_c + travel_c + health_c + hosp_c + other_c
replace tot_c_edt = -4 if miss>0
replace tot_c_edt=-1 if miss == (med_c==-1)+(travel_c==-1)+(health_c==-1)+(hosp_c==-1)+(other_c==-1)
replace tot_c_edt=-2 if miss == (med_c==-2)+(travel_c==-2)+(health_c==-2)+(hosp_c==-2)+(other_c==-2)
replace tot_c_edt=-3 if miss == (med_c==-3)+(travel_c==-3)+(health_c==-3)+(hosp_c==-3)+(other_c==-3)
replace tot_c_edt = total_c if tot_c_edt<0 & total_c>=0
label var tot_c_edt "total amount spent from items or summary question"
label val tot_c_edt q12
move tot_c_edt savings
drop miss
*
label drop a1_1
label drop q2
label val dieinj_yn q5a
sort hhid2004 pcode
save temp, replace
*
* ROSTER2004
*
use temp_roster, clear
*
* drop null records created during data entry for households with no new members
*
drop if pcode==-2
*
* correct mismatches revealed in inconsistencies in reported ages and related errors
*
replace pcode=103 if hhid2004==243006000 & pcode==41 /* NOT 41, SO GIVE NEW PCODE */
replace pcode=115 if hhid2004==221011040 & pcode==1  /* SAME NAME AS HER NIECE BUT MUCH OLDER */
replace relhd93=19 if hhid2004==221011040 & pcode==115
replace relhd93=5 if hhid2004==221011040 & pcode==43
replace pcode=104 if hhid2004==80003000 & pcode==6 /* NOT THE DEAD GRANDFATHER, SO GIVE NEW PCODE */
*
drop if pcode==9 & hhid2004==238016020
replace pcode=9 if hhid2004==238016020 & pcode==43 /* THIS IS THE OTHER STHEMBILE */
replace mother=9 if hhid2004==238016020 & pcode==44 /* THIS 26 YR OLD IS THE 1ST STHEMBILE, NOT SNEGUGU */
replace relhd93=18 if hhid2004==238016020 & pcode==44
drop if hhid==238016040 & pcode==43
replace pcode=43 if hhid==238016040 & pcode==44
replace mother=-4 if hhid==238016040 & pcode==43
replace relhd93=6 if hhid==238016040 & pcode==43
replace relhd93=18 if hhid==238016040 & pcode==45
*
replace mother=40 if hhid2004==80011000 & pcode==45
replace mother=40 if hhid2004==80011000 & pcode==46
replace mother=40 if hhid2004==80011000 & pcode==47
*
replace resident=2 if resident==-2 & lived==1 & hhid2004==223017004 & pcode==9
*
* tidy up variables and labels
*
rename alive98 alive
replace lived=1 if pcode>=100 & pcode<.
replace alive=1 if pcode>=100 & pcode<.
replace alive=3 if alive==-7
label def n1 3 "no: wrong 1998 report as dead", add
*
format hhid2004 %10.0f
format alive %15.0f
format qual_o %20s
format race %10.0f
format spouse %15.0f
format father %15.0f
format mother %15.0f
*
label var hhid2004 "9-digit KIDS-III household ID"
label var pcode "a3  person code"
label var relhd93 "a3a  relationship to head of household in 1993"
label var gender "a4  sex of person"
label var alive "n1  person is alive"
label var lived "n3  lived here 15+ days in the last year"
label var age "a5  age at interview in completed years"
label var activity "n5  main activity"
label var resident "a12  lived here 15+ days in the last month"
*
* add household and interview data to household member records
*
sort hhid2004 pcode
merge hhid2004 using temp_cover, uniqusing
replace agree_yn=1 if hhid2004==204010000 /* CONSENT FORM CHECKED - HAS BEEN SIGNED */
rename _merge cov_merge
tab cov_merge
*
* merge deaths into roster
*
label drop q6
label val care a5
sort hhid2004 pcode
merge hhid2004 pcode using temp, unique
rename _merge dth_merge
tab dth_merge ckn, m
*
* eliminate 4 duplicated households from all roster files
*
drop if hhid2004==234032004 | hhid2004==223016303 | hhid2004==236006005 | hhid2004 == 241004001
*
* (26-11-06) drop wrongly pre-printed records for pcode=40+ in 1998 split households
* 
* 22 records duplicated from 00 split households with no corresponding 1998 record
* plus 10 records duplicated from a 00 split that overwrote the correct record
*
drop if hhid2004==205011202 & (pcode==40 | pcode==41)
drop if hhid2004==209024240 & (pcode==60 | pcode==61)
drop if hhid2004==214007202 & (pcode==40 | pcode==41)
drop if hhid2004==216011202 & (pcode==40 | pcode==41 | pcode==42)
drop if hhid2004==219008202 & (pcode==40 | pcode==41 | pcode==42)
drop if (hhid2004==222014200 | hhid2004==222014300) & pcode==40
drop if (hhid2004==222014000 | hhid2004==222014300) & pcode==41
drop if (hhid2004==222014000 | hhid2004==222014200) & pcode==42
drop if hhid2004==224008040 & (pcode==42 | pcode==43 | pcode==45)
drop if hhid2004==237015202 & pcode==40
drop if hhid2004==238016202 & (pcode==41 | (pcode>=43 & pcode<=45))
drop if hhid2004==242008220 & (pcode==40 | pcode==41 | pcode==42)
drop if hhid2004==244015202 & pcode==40
*
* drop prelisted individuals who do not belong to k and n households
*
drop if qtype>1 & qtype<. & pcode<100 & (alive~=1 | lived==2) & s1_4_flag~=1
*
* LINK TO 1998 DATA
*
* main match (excepting girl who changed 1998 households)
*
save temp, replace
use "roster 1998 less 2 clusters only.dta", clear
sort hhid pcode
save "roster 1998 less 2 clusters only.dta", replace
use temp, clear
gen long hhid=int(hhid2004/100)
replace hhid=-1 if hhid2004==222014200 & pcode==41
sort hhid pcode
merge hhid pcode using "roster 1998 less 2 clusters only.dta", nokeep
rename _merge r98_merge
tab r98_merge
replace hhid=2220142 if hhid==-1
save temp, replace
*
* match 4 people whose record appears in different split households in 1998 and 2004
*
use "roster 1998 less 2 clusters only.dta", clear
drop oldid
gen long oldid=int(hhid/10)
replace oldid=-1 if ((pcode~=41 & pcode~=42) | hhid~=2220140) & ((pcode~=40 & pcode~=42) | hhid~=2380160)
sort oldid pcode
save "roster 1998 less 2 clusters only.dta", replace
use temp, clear
drop oldid
gen long oldid=int(hhid/10) if r98_merge~=3 /* ONLY MATCH ON 1993 ID IF MATCH ON 1998 ID FAILED */
sort oldid pcode
merge oldid pcode using "roster 1998 less 2 clusters only.dta", nokeep update
replace hhid=int(hhid2004/100)
replace oldid=int(hhid/10)
drop cluster metro
rename _merge r98_merge2
tab r98_merge2 r98_merge
*
* DEATHS - create file of & then drop individuals who had died by 1998
*
gen flag1 = alive<=-6 & (resident98==1 | pcode>=40)
replace alive=2 if flag1
save temp, replace
*
drop if alive> -6 | flag1
sort hhid pcode hhid2004
drop if hhid==hhid[_n-1] & pcode==pcode[_n-1]
sort hhid pcode
keep hhid pcode alive
save pre_1998_deaths_uniq, replace
*
use temp, clear
drop if alive==-8 | alive==-6
*
* create valid person records for deaths in extinct core households
*
replace qtype=0 if ckn==-2
label def qtype 0 "extinct core death", add
tab qtype dth_merge
drop ckn
*
replace a1=int(hhid2004/10000000) if qtype==0
replace agree_yn=1 if qtype==0 /* THE k AND n HOUSEHOLDS SUPPLYING THESE DATA CONSENTED */
replace alive=2 if qtype==0
replace cores=-2 if qtype==0
replace cores=1 if qtype==0 & (origcore=="C" | newcore=="C")
replace relhd93=relhd93_98 if qtype==0
replace gender=2-gender98 if qtype==0
*
replace lived=-2 if qtype==0
replace age=-2 if qtype==0
replace activity=-2 if qtype==0
replace resident=-2 if qtype==0
replace resp=-2 if qtype==0
replace educ=-2 if qtype==0
replace race=-2 if qtype==0
replace spouse=-2 if qtype==0
replace mother=-2 if qtype==0
replace father=-2 if qtype==0
replace care=-2 if qtype==0
replace dob_year=-2 if qtype==0
replace dob_month=-2 if qtype==0
replace dob_day=-2 if qtype==0
*
* choose most plausible report if 2 households disagree about whether person is dead
* (assume dead if date of death reported in later interview is after the 1st interview;
* assume alive if person is reported to live in the household, 
* otherwise assume dead if specific data provided on death; else assume alive)
*
drop if hhid==2110350 & pcode==5 & alive~=2
drop if hhid==2230090 & pcode==4 & alive~=2
drop if hhid==2230163 & pcode==3 & alive~=2
drop if hhid==2250030 & pcode==41 & alive~=1
drop if hhid==2250190 & pcode==10 & alive~=1
drop if hhid==2320050 & pcode==4 & alive~=1
drop if hhid==2380180 & pcode==12 & alive~=2
drop if hhid==2400240 & pcode==5 & alive~=1
*
* drop duplicate death reports by two split households
* (assign death to the 1998 household if it reports a date of death;
* otherwise to the household that reports the most complete date of death;
* droppinh households where DRA reported death occurred before 1998 in prefernce to others)
*
sort hhid pcode hhid2004
drop if flag1 & (alive>=2 & alive[_n-1]>=2 & hhid[_n-1]==hhid & pcode[_n-1]==pcode & die_daty[_n-1]>0 & die_datm[_n-1]>0 & lived98[_n-1]==1) /* 
*/ | (alive>=2 & alive[_n-2]>=2 & hhid[_n-2]==hhid & pcode[_n-2]==pcode & die_daty[_n-2]>0 & die_datm[_n-2]>0 & lived98[_n-2]==1)    /* 
*/ | (alive>=2 & alive[_n-3]>=2 & hhid[_n-3]==hhid & pcode[_n-3]==pcode & die_daty[_n-3]>0 & die_datm[_n-3]>0 & lived98[_n-3]==1)
drop if flag1 & (alive>=2 & alive[_n+1]>=2 & hhid[_n+1]==hhid & pcode[_n+1]==pcode & die_daty[_n+1]>0 & die_datm[_n+1]>0 & lived98[_n+1]==1)    /*
*/ | (alive>=2 & alive[_n+2]>=2 & hhid[_n+2]==hhid & pcode[_n+2]==pcode & die_daty[_n+2]>0 & die_datm[_n+2]>0 & lived98[_n+2]==1)    /*
*/ | (alive>=2 & alive[_n+3]>=2 & hhid[_n+3]==hhid & pcode[_n+3]==pcode & die_daty[_n+3]>0 & die_datm[_n+3]>0 & lived98[_n+3]==1)
drop if (alive>=2 & alive[_n-1]>=2 & hhid[_n-1]==hhid & pcode[_n-1]==pcode & die_daty[_n-1]>0 & die_datm[_n-1]>0 & lived98[_n-1]==1) /* 
*/ | (alive>=2 & alive[_n-2]>=2 & hhid[_n-2]==hhid & pcode[_n-2]==pcode & die_daty[_n-2]>0 & die_datm[_n-2]>0 & lived98[_n-2]==1)    /* 
*/ | (alive>=2 & alive[_n-3]>=2 & hhid[_n-3]==hhid & pcode[_n-3]==pcode & die_daty[_n-3]>0 & die_datm[_n-3]>0 & lived98[_n-3]==1)
drop if (alive>=2 & alive[_n+1]>=2 & hhid[_n+1]==hhid & pcode[_n+1]==pcode & die_daty[_n+1]>0 & die_datm[_n+1]>0 & lived98[_n+1]==1)    /*
*/ | (alive>=2 & alive[_n+2]>=2 & hhid[_n+2]==hhid & pcode[_n+2]==pcode & die_daty[_n+2]>0 & die_datm[_n+2]>0 & lived98[_n+2]==1)    /*
*/ | (alive>=2 & alive[_n+3]>=2 & hhid[_n+3]==hhid & pcode[_n+3]==pcode & die_daty[_n+3]>0 & die_datm[_n+3]>0 & lived98[_n+3]==1)


drop if flag1 & (alive>=2 & alive[_n-1]>=2 & hhid[_n-1]==hhid & pcode[_n-1]==pcode & die_daty[_n-1]>0 & lived98[_n-1]==1) /* 
*/ | (alive>=2 & alive[_n-2]>=2 & hhid[_n-2]==hhid & pcode[_n-2]==pcode & die_daty[_n-2]>0 & lived98[_n-2]==1)    /* 
*/ | (alive>=2 & alive[_n-3]>=2 & hhid[_n-3]==hhid & pcode[_n-3]==pcode & die_daty[_n-3]>0 & lived98[_n-3]==1)
drop if flag1 & (alive>=2 & alive[_n+1]>=2 & hhid[_n+1]==hhid & pcode[_n+1]==pcode & die_daty[_n+1]>0 & lived98[_n+1]==1) /*
*/ | (alive>=2 & alive[_n+2]>=2 & hhid[_n+2]==hhid & pcode[_n+2]==pcode & die_daty[_n+2]>0 & lived98[_n+2]==1)    /*
*/ | (alive>=2 & alive[_n+3]>=2 & hhid[_n+3]==hhid & pcode[_n+3]==pcode & die_daty[_n+3]>0 & lived98[_n+3]==1)
drop if (alive>=2 & alive[_n-1]>=2 & hhid[_n-1]==hhid & pcode[_n-1]==pcode & die_daty[_n-1]>0 & lived98[_n-1]==1) /* 
*/ | (alive>=2 & alive[_n-2]>=2 & hhid[_n-2]==hhid & pcode[_n-2]==pcode & die_daty[_n-2]>0 & lived98[_n-2]==1)    /* 
*/ | (alive>=2 & alive[_n-3]>=2 & hhid[_n-3]==hhid & pcode[_n-3]==pcode & die_daty[_n-3]>0 & lived98[_n-3]==1)
drop if (alive>=2 & alive[_n+1]>=2 & hhid[_n+1]==hhid & pcode[_n+1]==pcode & die_daty[_n+1]>0 & lived98[_n+1]==1) /*
*/ | (alive>=2 & alive[_n+2]>=2 & hhid[_n+2]==hhid & pcode[_n+2]==pcode & die_daty[_n+2]>0 & lived98[_n+2]==1)    /*
*/ | (alive>=2 & alive[_n+3]>=2 & hhid[_n+3]==hhid & pcode[_n+3]==pcode & die_daty[_n+3]>0 & lived98[_n+3]==1)

drop if flag1 & (alive>=2 & alive[_n-1]>=2 & hhid[_n-1]==hhid & pcode[_n-1]==pcode & die_daty[_n-1]>0 & die_datm[_n-1]>0) /* 
*/ | (alive>=2 & alive[_n-2]>=2 & hhid[_n-2]==hhid & pcode[_n-2]==pcode & die_daty[_n-2]>0 & die_datm[_n-2]>0)    /* 
*/ | (alive>=2 & alive[_n-3]>=2 & hhid[_n-3]==hhid & pcode[_n-3]==pcode & die_daty[_n-3]>0 & die_datm[_n-3]>0)
drop if flag1 & (alive>=2 & alive[_n+1]>=2 & hhid[_n+1]==hhid & pcode[_n+1]==pcode & die_daty[_n+1]>0 & die_datm[_n+1]>0) /*
*/ | (alive>=2 & alive[_n+2]>=2 & hhid[_n+2]==hhid & pcode[_n+2]==pcode & die_daty[_n+2]>0 & die_datm[_n+2]>0)    /*
*/ | (alive>=2 & alive[_n+3]>=2 & hhid[_n+3]==hhid & pcode[_n+3]==pcode & die_daty[_n+3]>0 & die_datm[_n+3]>0)
drop if (alive>=2 & alive[_n-1]>=2 & hhid[_n-1]==hhid & pcode[_n-1]==pcode & die_daty[_n-1]>0 & die_datm[_n-1]>0) /* 
*/ | (alive>=2 & alive[_n-2]>=2 & hhid[_n-2]==hhid & pcode[_n-2]==pcode & die_daty[_n-2]>0 & die_datm[_n-2]>0)    /* 
*/ | (alive>=2 & alive[_n-3]>=2 & hhid[_n-3]==hhid & pcode[_n-3]==pcode & die_daty[_n-3]>0 & die_datm[_n-3]>0)
drop if (alive>=2 & alive[_n+1]>=2 & hhid[_n+1]==hhid & pcode[_n+1]==pcode & die_daty[_n+1]>0 & die_datm[_n+1]>0) /*
*/ | (alive>=2 & alive[_n+2]>=2 & hhid[_n+2]==hhid & pcode[_n+2]==pcode & die_daty[_n+2]>0 & die_datm[_n+2]>0)    /*
*/ | (alive>=2 & alive[_n+3]>=2 & hhid[_n+3]==hhid & pcode[_n+3]==pcode & die_daty[_n+3]>0 & die_datm[_n+3]>0)

drop if flag1 & (alive>=2 & alive[_n-1]>=2 & hhid[_n-1]==hhid & pcode[_n-1]==pcode & (die_daty[_n-1]>0 | die_daty<0)) /* 
*/ | (alive>=2 & alive[_n-2]>=2 & hhid[_n-2]==hhid & pcode[_n-2]==pcode & (die_daty[_n-2]>0 | die_daty<0))    /* 
*/ | (alive>=2 & alive[_n-3]>=2 & hhid[_n-3]==hhid & pcode[_n-3]==pcode & (die_daty[_n-3]>0 | die_daty<0))
drop if flag1 & (alive>=2 & alive[_n+1]>=2 & hhid[_n+1]==hhid & pcode[_n+1]==pcode & (die_daty[_n+1]>0 | die_daty<0)) /*
*/ | (alive>=2 & alive[_n+2]>=2 & hhid[_n+2]==hhid & pcode[_n+2]==pcode & (die_daty[_n+2]>0 | die_daty<0))    /*
*/ | (alive>=2 & alive[_n+3]>=2 & hhid[_n+3]==hhid & pcode[_n+3]==pcode & (die_daty[_n+3]>0 | die_daty<0))
drop if (alive>=2 & alive[_n-1]>=2 & hhid[_n-1]==hhid & pcode[_n-1]==pcode & (die_daty[_n-1]>0 | die_daty<0)) /* 
*/ | (alive>=2 & alive[_n-2]>=2 & hhid[_n-2]==hhid & pcode[_n-2]==pcode & (die_daty[_n-2]>0 | die_daty<0))    /* 
*/ | (alive>=2 & alive[_n-3]>=2 & hhid[_n-3]==hhid & pcode[_n-3]==pcode & (die_daty[_n-3]>0 | die_daty<0))
drop if (alive>=2 & alive[_n+1]>=2 & hhid[_n+1]==hhid & pcode[_n+1]==pcode & (die_daty[_n+1]>0 | die_daty<0)) /*
*/ | (alive>=2 & alive[_n+2]>=2 & hhid[_n+2]==hhid & pcode[_n+2]==pcode & (die_daty[_n+2]>0 | die_daty<0))    /*
*/ | (alive>=2 & alive[_n+3]>=2 & hhid[_n+3]==hhid & pcode[_n+3]==pcode & (die_daty[_n+3]>0 | die_daty<0))

drop if flag1 & (alive>=2 & alive[_n-1]>=2 & hhid[_n-1]==hhid & pcode[_n-1]==pcode & lived98[_n-1]==1) /* 
*/ | (alive>=2 & alive[_n-2]>=2 & hhid[_n-2]==hhid & pcode[_n-2]==pcode & lived98[_n-2]==1)    /* 
*/ | (alive>=2 & alive[_n-3]>=2 & hhid[_n-3]==hhid & pcode[_n-3]==pcode & lived98[_n-3]==1)
drop if flag1 & (alive>=2 & alive[_n+1]>=2 & hhid[_n+1]==hhid & pcode[_n+1]==pcode & lived98[_n+1]==1) /*
*/ | (alive>=2 & alive[_n+2]>=2 & hhid[_n+2]==hhid & pcode[_n+2]==pcode & lived98[_n+2]==1)    /*
*/ | (alive>=2 & alive[_n+3]>=2 & hhid[_n+3]==hhid & pcode[_n+3]==pcode & lived98[_n+3]==1)
drop if (alive>=2 & alive[_n-1]>=2 & hhid[_n-1]==hhid & pcode[_n-1]==pcode & lived98[_n-1]==1) /* 
*/ | (alive>=2 & alive[_n-2]>=2 & hhid[_n-2]==hhid & pcode[_n-2]==pcode & lived98[_n-2]==1)    /* 
*/ | (alive>=2 & alive[_n-3]>=2 & hhid[_n-3]==hhid & pcode[_n-3]==pcode & lived98[_n-3]==1)
drop if (alive>=2 & alive[_n+1]>=2 & hhid[_n+1]==hhid & pcode[_n+1]==pcode & lived98[_n+1]==1) /*
*/ | (alive>=2 & alive[_n+2]>=2 & hhid[_n+2]==hhid & pcode[_n+2]==pcode & lived98[_n+2]==1)    /*
*/ | (alive>=2 & alive[_n+3]>=2 & hhid[_n+3]==hhid & pcode[_n+3]==pcode & lived98[_n+3]==1)
*
* identify duplicate records
*
sort oldid pcode hhid hhid2004
gen flag = (((oldid==oldid[_n-1] & pcode==pcode[_n-1]) | (oldid==oldid[_n+1] & pcode==pcode[_n+1])) & pcode<40) /*
*/ | (((hhid==hhid[_n-1] & pcode==pcode[_n-1]) | (hhid==hhid[_n+1] & pcode==pcode[_n+1])) & pcode<100)
egen wave=cut(pcode), at(1,40,100,999) icode label
tab flag wave
*
* drop duplicate death reports by households that split before 1998 (assign to 1998 household)
*
drop if flag & flag1 & ((alive>=2 & alive[_n-1]>=2 & oldid[_n-1]==oldid & pcode[_n-1]==pcode & lived98[_n-1]==1)  /*
*/ | (alive>=2 & alive[_n-2]>=2 & oldid[_n-2]==oldid & pcode[_n-2]==pcode & lived98[_n-2]==1)                /* 
*/ | (alive>=2 & alive[_n-3]>=2 & oldid[_n-3]==oldid & pcode[_n-3]==pcode & lived98[_n-3]==1))
drop if flag & flag1 & ((alive>=2 & alive[_n+1]>=2 & oldid[_n+1]==oldid & pcode[_n+1]==pcode & lived98[_n+1]==1)  /* 
*/ | (alive>=2 & alive[_n+2]>=2 & oldid[_n+2]==oldid & pcode[_n+2]==pcode & lived98[_n+2]==1)                /* 
*/ | (alive>=2 & alive[_n+3]>=2 & oldid[_n+3]==oldid & pcode[_n+3]==pcode & lived98[_n+3]==1))
drop if flag & ((alive>=2 & alive[_n-1]>=2 & oldid[_n-1]==oldid & pcode[_n-1]==pcode & lived98[_n-1]==1)  /*
*/ | (alive>=2 & alive[_n-2]>=2 & oldid[_n-2]==oldid & pcode[_n-2]==pcode & lived98[_n-2]==1)                /* 
*/ | (alive>=2 & alive[_n-3]>=2 & oldid[_n-3]==oldid & pcode[_n-3]==pcode & lived98[_n-3]==1))
drop if flag  & ((alive>=2 & alive[_n+1]>=2 & oldid[_n+1]==oldid & pcode[_n+1]==pcode & lived98[_n+1]==1)  /* 
*/ | (alive>=2 & alive[_n+2]>=2 & oldid[_n+2]==oldid & pcode[_n+2]==pcode & lived98[_n+2]==1)                /* 
*/ | (alive>=2 & alive[_n+3]>=2 & oldid[_n+3]==oldid & pcode[_n+3]==pcode & lived98[_n+3]==1))
tab flag1
drop flag1
*
* DROP DUPLICATE RECORDS FOR LIVING INDIVIDUALS
*
* drop if index household does not know if the person is alive and another household does
*
drop if ((oldid==oldid[_n-1] & pcode==pcode[_n-1] & alive<1 & alive[_n-1]==1)/*
*/ |  (oldid==oldid[_n-2] & pcode==pcode[_n-2] & alive<1 & alive[_n-2]==1)   /*
*/ |  (oldid==oldid[_n-3] & pcode==pcode[_n-3] & alive<1 & alive[_n-3]==1)) & flag==1
drop if ((hhid==hhid[_n+1] & pcode==pcode[_n+1] & alive<1 & alive[_n+1]==1)/*
*/ |  (oldid==oldid[_n+2] & pcode==pcode[_n+2] & alive<1 & alive[_n+2]==1)   /*
*/ |  (oldid==oldid[_n+3] & pcode==pcode[_n+3] & alive<1 & alive[_n+3]==1)) & flag==1
*
* drop those who were not members in 2004 if they belong to another split household
*
drop if ((lived~=1 & lived[_n-1]==1 & oldid[_n-1]==oldid & pcode[_n-1]==pcode & s1_4_flag~=1)/* 
*/ | (lived~=1 & lived[_n-2]==1 & oldid[_n-2]==oldid & pcode[_n-2]==pcode & s1_4_flag~=1)    /* 
*/ | (lived~=1 & lived[_n-3]==1 & oldid[_n-3]==oldid & pcode[_n-3]==pcode & s1_4_flag~=1)) & flag==1
drop if ((lived~=1 & lived[_n+1]==1 & oldid[_n+1]==oldid & pcode[_n+1]==pcode & s1_4_flag~=1)/* 
*/ | (lived~=1 & lived[_n+2]==1 & oldid[_n+2]==oldid & pcode[_n+2]==pcode & s1_4_flag~=1)    /*  
*/ | (lived~=1 & lived[_n+3]==1 & oldid[_n+3]==oldid & pcode[_n+3]==pcode & s1_4_flag~=1)) & flag==1 
*
* drop non-members who belong to another 1998 household or are also listed in their 1998 household
*
drop if flag==1 & ((lived~=1 & lived98[_n-1]==1 & oldid[_n-1]==oldid & pcode[_n-1]==pcode & r98_merge2==5 & s1_4_flag~=1) /*
*/ | (lived~=1 & lived98[_n-2]==1 & oldid[_n-2]==oldid & pcode[_n-2]==pcode & r98_merge2==5 & s1_4_flag~=1)    /*
*/ | (lived~=1 & lived98[_n-3]==1 & oldid[_n-3]==oldid & pcode[_n-3]==pcode & r98_merge2==5 & s1_4_flag~=1))
drop if flag==1 & ((lived~=1 & lived98[_n+1]==1 & oldid[_n+1]==oldid & pcode[_n+1]==pcode & r98_merge2==5 & s1_4_flag~=1) /*
*/ | (lived~=1 & lived98[_n+2]==1 & oldid[_n+2]==oldid & pcode[_n+2]==pcode & r98_merge2==5 & s1_4_flag~=1)    /*
*/ | (lived~=1 & lived98[_n+3]==1 & oldid[_n+3]==oldid & pcode[_n+3]==pcode & r98_merge2==5 & s1_4_flag~=1))

replace flag = (((oldid==oldid[_n-1] & pcode==pcode[_n-1]) | (oldid==oldid[_n+1] & pcode==pcode[_n+1])) & pcode<40) /*
*/ | (((hhid==hhid[_n-1] & pcode==pcode[_n-1]) | (hhid==hhid[_n+1] & pcode==pcode[_n+1])) & pcode<100) 
tab flag wave
drop flag wave
* drop if hhid2004==227006000 & pcode==103 /* same child probably resides 2 households but leave as so does mum */

*
* RECALCULATE AGE FROM DATES OF INTERVIEW AND BIRTH (if known) OR 1998 AGE IF NO 2004 DATA
*
replace dob_year=1993 if hhid2004==227006020 & pcode==41 /* MISPUNCHED AS 1983 - INCONSISTENT WITH 1998 */
replace age=10 if hhid2004==227006020 & pcode==41 & age==21 
gen long newdob = mdy(dob_month,dob_day,dob_year)
replace newdob = mdy(dob_month,15,dob_year) if dob_day<1 
replace newdob = mdy(6,30,dob_year) if dob_month<1 
replace newdob= . if dob_year<1
gen int age_dob = age
replace age_dob = int((a7d-newdob)/365.25) if a7d~=. & newdob~=. & (dob_month>0 | age<0)
replace age_dob = age if age_dob<5 & pcode<100 & age_dob<age
replace age_dob = age98+int((a7d-date98)/365.25) if lived==1 & pcode<100 & age98>=0 & a7d~=. & age_dob<6 /* age_dob MISSING OR IMPOSSIBLY YOUNG */
label var age_dob "Age using birth date/2004 age/1998 age"
label values age_dob a5
tab age_dob if (pcode>100 | lived==1) & age_dob<0, miss
drop newdob
move age_dob a1
*
* SECTION 1_5
*
replace mother=-4 if mother>72 & mother<88
replace father=-4 if father>72 & father<88
replace spouse=99 if spouse==98
replace mother=99 if mother==98
replace father=99 if father==98
*
label var spouse "n3  spouse or partner of household member"
label def relatives -4 "missing" -3 "refused" -1 "do not know" 78 "never married" 79 "divorced or separated" 88 "deceased"  93 "multiple wives" 99 "lives elsewhere"
label value spouse relatives
label value father relatives
label value mother relatives
label def  race -4 "missing" -1 "do not know" 1 "black african" 2 "coloured" 3 "indian" 4 "white"
label value race race
*
* DELETE WORK VARIABLES
*
tab s1_4_flag
drop s1_4_flag dth_merge r98_merge r98_merge2 cov_merge oldid
*
* LIST MISSING SECTION 1_3'S
*
list hhid2004 pcode lived98 resident98 age98 alive intvwr1 if die_daty==-4, table clean
*
* SAVE FULL FILE AND SEPARATE COVER, ROSTER AND SECTION 1.3 FILES
*
sort hhid2004 pcode
save new_roster, replace
*
drop clustnum date98 supcode hhid-relhd98
save temp, replace
drop a1-loans_b activito qual_o spouse_o father_o mother_o
save roster2004, replace
*
use temp, clear
drop if alive<2
drop qtype-anthcode4 nocons_o
foreach var of varlist die_datm-care_cons nocons-loans_b {
replace `var' = -4 if `var'==. & loans_b==.
}
save section1_3, replace
*
use temp, clear
keep if hhid2004~=hhid2004[_n-1]
drop pcode cores-age_dob die_datm-loans_b sect
move a1 qtype
rename a1 cluster
save cover, replace
*
* finalise SECTION 1.4
*
use section1_4, clear
merge hhid2004 using cover, keep(qtype)
drop if _merge<3
label drop qtype
keep hhid2004 dec_makr
sort hhid2004 dec_makr
save section1_4, replace
*
* SECTION 1.6: add in missed records (no information was lost as her parents are listed)
*
clear
input double hhid2004 resp pcode parent plisted ppcode palv_agdt page04 pfinance pactiv peduc
 219010024 -4 4 1 1 -2 -2 -2 -2 -2 -2
 219010024 -4 4 2 1 -2 -2 -2 -2 -2 -2
end
save temp, replace
use "section1_6 raw", clear
sort hhid2004 pcode
compress resp-peduc
*
replace ppcode=-2 if plisted==1
replace pcode=44 if hhid2004==238016020 & pcode==43 /* TO MATCH ROSTER EDIT */
drop if hhid2004==219010024 & pcode==8 /* PERSON IS NEXT GENERATION, NOT CORE */
replace parent=2 if parent==4
*
drop qtype a1
label drop n2 n5
label values ppcode resp
label values plisted n7
label def n2 -5 "other" -4 "missing" -3 "refused" -2 "not applic" -1 "do not know" 1 "mother" 2 "father" 
label values parent n2
label def n5 -5 "other" -4 "missing" -3 "refused" -2 "not applic" -1 "do not know" 1 "alive"
label values palv_agdt n5
*
sort hhid2004 pcode
save section1_6, replace
*
* merge section 1_6 into roster
*
use new_roster, clear
sort hhid2004 pcode
merge hhid2004 pcode using section1_6, uniqmaster
*
* checks on section 1.6 (all now OK)
*
tab _merge qtype, miss
tab _merge cores if qtype==2, miss
tab _merge resident if qtype==2 & cores==1, miss
tab ppcode plisted if _merge==3 & cores==1, miss
tab palv_agdt parent if _merge==3 & cores==1 & plisted==2, miss
tab page04 parent if _merge==3 & cores==1 & plisted==2 & palv_agdt==1, miss
tab pfinance parent if _merge==3 & cores==1 & plisted==2 & palv_agdt==1, miss
tab pactiv parent if _merge==3 & cores==1 & plisted==2 & palv_agdt==1, miss
*
erase "temp.dta"
erase "temp_roster.dta"
erase "temp_cover.dta"
erase "new_roster.dta"
log close
